import { AwsSdkSigV4AuthInputConfig, AwsSdkSigV4AuthResolvedConfig, AwsSdkSigV4PreviouslyResolved } from "@aws-sdk/core";
import { HandlerExecutionContext, HttpAuthScheme, HttpAuthSchemeParameters, HttpAuthSchemeParametersProvider, HttpAuthSchemeProvider } from "@smithy/types";
import { DataBrewClientResolvedConfig } from "../DataBrewClient";
/**
 * @internal
 */
export interface DataBrewHttpAuthSchemeParameters extends HttpAuthSchemeParameters {
    region?: string;
}
/**
 * @internal
 */
export interface DataBrewHttpAuthSchemeParametersProvider extends HttpAuthSchemeParametersProvider<DataBrewClientResolvedConfig, HandlerExecutionContext, DataBrewHttpAuthSchemeParameters, object> {
}
/**
 * @internal
 */
export declare const defaultDataBrewHttpAuthSchemeParametersProvider: (config: DataBrewClientResolvedConfig, context: HandlerExecutionContext, input: object) => Promise<DataBrewHttpAuthSchemeParameters>;
/**
 * @internal
 */
export interface DataBrewHttpAuthSchemeProvider extends HttpAuthSchemeProvider<DataBrewHttpAuthSchemeParameters> {
}
/**
 * @internal
 */
export declare const defaultDataBrewHttpAuthSchemeProvider: DataBrewHttpAuthSchemeProvider;
/**
 * @internal
 */
export interface HttpAuthSchemeInputConfig extends AwsSdkSigV4AuthInputConfig {
    /**
     * Configuration of HttpAuthSchemes for a client which provides default identity providers and signers per auth scheme.
     * @internal
     */
    httpAuthSchemes?: HttpAuthScheme[];
    /**
     * Configuration of an HttpAuthSchemeProvider for a client which resolves which HttpAuthScheme to use.
     * @internal
     */
    httpAuthSchemeProvider?: DataBrewHttpAuthSchemeProvider;
}
/**
 * @internal
 */
export interface HttpAuthSchemeResolvedConfig extends AwsSdkSigV4AuthResolvedConfig {
    /**
     * Configuration of HttpAuthSchemes for a client which provides default identity providers and signers per auth scheme.
     * @internal
     */
    readonly httpAuthSchemes: HttpAuthScheme[];
    /**
     * Configuration of an HttpAuthSchemeProvider for a client which resolves which HttpAuthScheme to use.
     * @internal
     */
    readonly httpAuthSchemeProvider: DataBrewHttpAuthSchemeProvider;
}
/**
 * @internal
 */
export declare const resolveHttpAuthSchemeConfig: <T>(config: T & HttpAuthSchemeInputConfig & AwsSdkSigV4PreviouslyResolved) => T & HttpAuthSchemeResolvedConfig;
